@@ -48,7 +48,10 @@ def launch_instance(
     return instance
 
 
-_BASE_URL = f"http://{settings.HOST_NAME}:{settings.DTALE_PORT}"
+if settings.DTALE_EXTERNAL_HOST_NAME is not None:
+    _BASE_URL = f"http://{settings.DTALE_EXTERNAL_HOST_NAME}"
+else:
+    _BASE_URL = f"http://{settings.HOST_NAME}:{settings.DTALE_PORT}"
 
 
 def get_main_url(data_id: Union[str, int]) -> str:
