@@ -372,7 +372,7 @@ class Node(BaseApiModel):
             if instance is None:
                 data = await self.get_data()
                 instance = dtale_app.launch_instance(data=data, data_id=self.data_id)
-                self.dtale_url = instance.main_url()
+                self.dtale_url = dtale_app.get_main_url(self.data_id)
                 self.dtale_charts_url = dtale_app.get_charts_url(self.data_id)
                 self.dtale_describe_url = dtale_app.get_describe_url(self.data_id)
                 self.dtale_correlations_url = dtale_app.get_correlations_url(
