@@ -1,10 +1,12 @@
 """
 Environment variables that can be used to configure settings:
 - DTALEDESKTOP_HOST
-- DTALEDESKTOP_PORT
-- DTALEDESKTOP_DTALE_PORT
 - DTALEDESKTOP_HOST_NAME
     used for building links, might be necessary if you're running this in a container.
+- DTALEDESKTOP_PORT
+- DTALEDESKTOP_DTALE_PORT
+- DTALEDESKTOP_DTALE_EXTERNAL_HOST_NAME
+    allow specifying something special here just to make running it in k8s under a different hostname simple
 - DTALEDESKTOP_ROOT_DIR:
     path, the location where all persistent data (loaders, cached data, etc.) will be stored.
     By default this is ~/.dtaledesktop
@@ -45,6 +47,7 @@ class _Settings:
     PORT: int
     DTALE_PORT: Optional[int]
     HOST_NAME: str
+    DTALE_EXTERNAL_HOST_NAME: str
 
     _instance = _SENTINEL
 
@@ -56,6 +59,10 @@ class _Settings:
         self._HOST = os.getenv("DTALEDESKTOP_HOST", None)
         self._HOST_NAME = os.getenv("DTALEDESKTOP_HOST_NAME", None)
 
+        self.DTALE_EXTERNAL_HOST_NAME = os.getenv(
+            "DTALEDESKTOP_DTALE_EXTERNAL_HOST_NAME", None
+        )
+
         try:
             self._PORT = int(os.getenv("DTALEDESKTOP_PORT"))
         except (ValueError, TypeError):
